// SPDX-License-Identifier: Apache-2.0
// Sealed with Magistamp.

//! A Rust tool to magically seal your source files with SPDX license headers.

mod project;
mod stamper;



use std::path::PathBuf;
use std::process::Command;
use std::io;

use crate::stamper::*;



/// Print the version of the project.
#[allow(dead_code)]
fn print_version()
{
   println!("{} v{}", project::get_name(), project::get_version());
}


fn get_workspace_root() -> io::Result<PathBuf> {
    let output = Command::new("cargo")
        .args(&["metadata", "--no-deps", "--format-version", "1"])
        .output()?;

    if !output.status.success() {
        return Err(io::Error::new(io::ErrorKind::Other, "cargo metadata failed"));
    }

    let metadata_json = String::from_utf8(output.stdout)
        .map_err(|e| io::Error::new(io::ErrorKind::InvalidData, e))?;

    let workspace_root = parse_workspace_root(&metadata_json)?;
    Ok(workspace_root)
}

fn parse_workspace_root(json: &str) -> io::Result<PathBuf> {

   match json.find("\"workspace_root\"")
   {
      None => {}

      Some(index) =>
      {
         let sub = &json[index+17..];
         let mut start = 0;
         let mut one_more = false;

         for (i, c) in sub.chars().enumerate()
         {
            if c == '"'
            {
               if !one_more
               {
                  start = i+1;
                  one_more = true;
               }
               else
               {
                  return Ok(PathBuf::from(sub[start..i].to_owned()));
               }
            }
         }
      }
   }

   Err(io::Error::new(io::ErrorKind::Other, "workspace_root not found"))
}


fn main() -> io::Result<()>
{
   let path = get_workspace_root()?;

   println!("workspace root: {}", path.display());
   Stamper::visit_dirs(&path)?;

   Ok(())
}
