// SPDX-License-Identifier: Apache-2.0
// Sealed with Magistamp.

use std::fs::{read_to_string, write};
use std::path::Path;
use std::{fs, io};



const SPDX_HEADER: &str = "// SPDX-License-Identifier:";
const STAMP: &str = "\
// SPDX-License-Identifier: Apache-2.0
// Sealed with Magistamp.

";



pub enum Stamper {}



impl Stamper
{
   pub fn visit_dirs(dir: &Path) -> io::Result<()>
   {
      if dir.is_dir()
      {
         for entry in fs::read_dir(dir)?
         {
            let entry = entry?;
            let path = entry.path();
            if path.is_dir()
            {
               Stamper::visit_dirs(&path)?;
            }
            else if path.extension().and_then(|s| s.to_str()) == Some("rs")
            {
               Stamper::process_file(&path);
            }
         }
      }

      Ok(())
   }

   fn process_file(path: &Path)
   {
      if let Ok(content) = read_to_string(path)
      {
         if content.starts_with(SPDX_HEADER)
         {
            return; // Already has a header
         }

         println!("🪄 Magistamp: sealing {} with SPDX protection...",
                  path.display());

         let new_content = format!("{STAMP}{content}");
         if let Err(e) = write(path, new_content)
         {
            eprintln!("Failed to write to {}: {}", path.display(), e);
         }
      }
   }
}
